@@ -1,3 +1,18 @@
+'''
+# Amazon Inspector Construct Library
+
+<!--BEGIN STABILITY BANNER-->---
+
+
+![cfn-resources: Stable](https://img.shields.io/badge/cfn--resources-stable-success.svg?style=for-the-badge)
+
+> All classes with the `Cfn` prefix in this module ([CFN Resources](https://docs.aws.amazon.com/cdk/latest/guide/constructs.html#constructs_lib)) are always stable and safe to use.
+
+---
+<!--END STABILITY BANNER-->
+
+This module is part of the [AWS Cloud Development Kit](https://github.com/aws/aws-cdk) project.
+'''
 import abc
 import builtins
 import datetime
@@ -26,11 +41,11 @@ class CfnAssessmentTarget(
     metaclass=jsii.JSIIMeta,
     jsii_type="monocdk.aws_inspector.CfnAssessmentTarget",
 ):
-    """A CloudFormation ``AWS::Inspector::AssessmentTarget``.
+    '''A CloudFormation ``AWS::Inspector::AssessmentTarget``.
 
-    :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-inspector-assessmenttarget.html
     :cloudformationResource: AWS::Inspector::AssessmentTarget
-    """
+    :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-inspector-assessmenttarget.html
+    '''
 
     def __init__(
         self,
@@ -40,13 +55,13 @@ class CfnAssessmentTarget(
         assessment_target_name: typing.Optional[builtins.str] = None,
         resource_group_arn: typing.Optional[builtins.str] = None,
     ) -> None:
-        """Create a new ``AWS::Inspector::AssessmentTarget``.
+        '''Create a new ``AWS::Inspector::AssessmentTarget``.
 
         :param scope: - scope in which this resource is defined.
         :param id: - scoped id of the resource.
         :param assessment_target_name: ``AWS::Inspector::AssessmentTarget.AssessmentTargetName``.
         :param resource_group_arn: ``AWS::Inspector::AssessmentTarget.ResourceGroupArn``.
-        """
+        '''
         props = CfnAssessmentTargetProps(
             assessment_target_name=assessment_target_name,
             resource_group_arn=resource_group_arn,
@@ -56,66 +71,64 @@ class CfnAssessmentTarget(
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: _TreeInspector_1cd1894e) -> None:
-        """(experimental) Examines the CloudFormation resource and discloses attributes.
+        '''Examines the CloudFormation resource and discloses attributes.
 
         :param inspector: - tree inspector to collect and process attributes.
-
-        :stability: experimental
-        """
-        return jsii.invoke(self, "inspect", [inspector])
+        '''
+        return typing.cast(None, jsii.invoke(self, "inspect", [inspector]))
 
     @jsii.member(jsii_name="renderProperties")
     def _render_properties(
         self,
         props: typing.Mapping[builtins.str, typing.Any],
     ) -> typing.Mapping[builtins.str, typing.Any]:
-        """
+        '''
         :param props: -
-        """
-        return jsii.invoke(self, "renderProperties", [props])
+        '''
+        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "renderProperties", [props]))
 
-    @jsii.python.classproperty # type: ignore
+    @jsii.python.classproperty # type: ignore[misc]
     @jsii.member(jsii_name="CFN_RESOURCE_TYPE_NAME")
     def CFN_RESOURCE_TYPE_NAME(cls) -> builtins.str:
-        """The CloudFormation resource type name for this resource class."""
-        return jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME")
+        '''The CloudFormation resource type name for this resource class.'''
+        return typing.cast(builtins.str, jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME"))
 
-    @builtins.property # type: ignore
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="attrArn")
     def attr_arn(self) -> builtins.str:
-        """
+        '''
         :cloudformationAttribute: Arn
-        """
-        return jsii.get(self, "attrArn")
+        '''
+        return typing.cast(builtins.str, jsii.get(self, "attrArn"))
 
-    @builtins.property # type: ignore
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="cfnProperties")
     def _cfn_properties(self) -> typing.Mapping[builtins.str, typing.Any]:
-        return jsii.get(self, "cfnProperties")
+        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.get(self, "cfnProperties"))
 
-    @builtins.property # type: ignore
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="assessmentTargetName")
     def assessment_target_name(self) -> typing.Optional[builtins.str]:
-        """``AWS::Inspector::AssessmentTarget.AssessmentTargetName``.
+        '''``AWS::Inspector::AssessmentTarget.AssessmentTargetName``.
 
-        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-inspector-assessmenttarget.html#cfn-inspector-assessmenttarget-assessmenttargetname
-        """
-        return jsii.get(self, "assessmentTargetName")
+        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-inspector-assessmenttarget.html#cfn-inspector-assessmenttarget-assessmenttargetname
+        '''
+        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "assessmentTargetName"))
 
-    @assessment_target_name.setter # type: ignore
+    @assessment_target_name.setter
     def assessment_target_name(self, value: typing.Optional[builtins.str]) -> None:
         jsii.set(self, "assessmentTargetName", value)
 
-    @builtins.property # type: ignore
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="resourceGroupArn")
     def resource_group_arn(self) -> typing.Optional[builtins.str]:
-        """``AWS::Inspector::AssessmentTarget.ResourceGroupArn``.
+        '''``AWS::Inspector::AssessmentTarget.ResourceGroupArn``.
 
-        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-inspector-assessmenttarget.html#cfn-inspector-assessmenttarget-resourcegrouparn
-        """
-        return jsii.get(self, "resourceGroupArn")
+        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-inspector-assessmenttarget.html#cfn-inspector-assessmenttarget-resourcegrouparn
+        '''
+        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "resourceGroupArn"))
 
-    @resource_group_arn.setter # type: ignore
+    @resource_group_arn.setter
     def resource_group_arn(self, value: typing.Optional[builtins.str]) -> None:
         jsii.set(self, "resourceGroupArn", value)
 
@@ -135,13 +148,13 @@ class CfnAssessmentTargetProps:
         assessment_target_name: typing.Optional[builtins.str] = None,
         resource_group_arn: typing.Optional[builtins.str] = None,
     ) -> None:
-        """Properties for defining a ``AWS::Inspector::AssessmentTarget``.
+        '''Properties for defining a ``AWS::Inspector::AssessmentTarget``.
 
         :param assessment_target_name: ``AWS::Inspector::AssessmentTarget.AssessmentTargetName``.
         :param resource_group_arn: ``AWS::Inspector::AssessmentTarget.ResourceGroupArn``.
 
-        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-inspector-assessmenttarget.html
-        """
+        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-inspector-assessmenttarget.html
+        '''
         self._values: typing.Dict[str, typing.Any] = {}
         if assessment_target_name is not None:
             self._values["assessment_target_name"] = assessment_target_name
@@ -150,21 +163,21 @@ class CfnAssessmentTargetProps:
 
     @builtins.property
     def assessment_target_name(self) -> typing.Optional[builtins.str]:
-        """``AWS::Inspector::AssessmentTarget.AssessmentTargetName``.
+        '''``AWS::Inspector::AssessmentTarget.AssessmentTargetName``.
 
-        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-inspector-assessmenttarget.html#cfn-inspector-assessmenttarget-assessmenttargetname
-        """
+        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-inspector-assessmenttarget.html#cfn-inspector-assessmenttarget-assessmenttargetname
+        '''
         result = self._values.get("assessment_target_name")
-        return result
+        return typing.cast(typing.Optional[builtins.str], result)
 
     @builtins.property
     def resource_group_arn(self) -> typing.Optional[builtins.str]:
-        """``AWS::Inspector::AssessmentTarget.ResourceGroupArn``.
+        '''``AWS::Inspector::AssessmentTarget.ResourceGroupArn``.
 
-        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-inspector-assessmenttarget.html#cfn-inspector-assessmenttarget-resourcegrouparn
-        """
+        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-inspector-assessmenttarget.html#cfn-inspector-assessmenttarget-resourcegrouparn
+        '''
         result = self._values.get("resource_group_arn")
-        return result
+        return typing.cast(typing.Optional[builtins.str], result)
 
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -184,11 +197,11 @@ class CfnAssessmentTemplate(
     metaclass=jsii.JSIIMeta,
     jsii_type="monocdk.aws_inspector.CfnAssessmentTemplate",
 ):
-    """A CloudFormation ``AWS::Inspector::AssessmentTemplate``.
+    '''A CloudFormation ``AWS::Inspector::AssessmentTemplate``.
 
-    :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-inspector-assessmenttemplate.html
     :cloudformationResource: AWS::Inspector::AssessmentTemplate
-    """
+    :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-inspector-assessmenttemplate.html
+    '''
 
     def __init__(
         self,
@@ -197,11 +210,11 @@ class CfnAssessmentTemplate(
         *,
         assessment_target_arn: builtins.str,
         duration_in_seconds: jsii.Number,
-        rules_package_arns: typing.List[builtins.str],
+        rules_package_arns: typing.Sequence[builtins.str],
         assessment_template_name: typing.Optional[builtins.str] = None,
-        user_attributes_for_findings: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union[_IResolvable_a771d0ef, _CfnTag_95fbdc29]]]] = None,
+        user_attributes_for_findings: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[_IResolvable_a771d0ef, _CfnTag_95fbdc29]]]] = None,
     ) -> None:
-        """Create a new ``AWS::Inspector::AssessmentTemplate``.
+        '''Create a new ``AWS::Inspector::AssessmentTemplate``.
 
         :param scope: - scope in which this resource is defined.
         :param id: - scoped id of the resource.
@@ -210,7 +223,7 @@ class CfnAssessmentTemplate(
         :param rules_package_arns: ``AWS::Inspector::AssessmentTemplate.RulesPackageArns``.
         :param assessment_template_name: ``AWS::Inspector::AssessmentTemplate.AssessmentTemplateName``.
         :param user_attributes_for_findings: ``AWS::Inspector::AssessmentTemplate.UserAttributesForFindings``.
-        """
+        '''
         props = CfnAssessmentTemplateProps(
             assessment_target_arn=assessment_target_arn,
             duration_in_seconds=duration_in_seconds,
@@ -223,107 +236,105 @@ class CfnAssessmentTemplate(
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: _TreeInspector_1cd1894e) -> None:
-        """(experimental) Examines the CloudFormation resource and discloses attributes.
+        '''Examines the CloudFormation resource and discloses attributes.
 
         :param inspector: - tree inspector to collect and process attributes.
-
-        :stability: experimental
-        """
-        return jsii.invoke(self, "inspect", [inspector])
+        '''
+        return typing.cast(None, jsii.invoke(self, "inspect", [inspector]))
 
     @jsii.member(jsii_name="renderProperties")
     def _render_properties(
         self,
         props: typing.Mapping[builtins.str, typing.Any],
     ) -> typing.Mapping[builtins.str, typing.Any]:
-        """
+        '''
         :param props: -
-        """
-        return jsii.invoke(self, "renderProperties", [props])
+        '''
+        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "renderProperties", [props]))
 
-    @jsii.python.classproperty # type: ignore
+    @jsii.python.classproperty # type: ignore[misc]
     @jsii.member(jsii_name="CFN_RESOURCE_TYPE_NAME")
     def CFN_RESOURCE_TYPE_NAME(cls) -> builtins.str:
-        """The CloudFormation resource type name for this resource class."""
-        return jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME")
+        '''The CloudFormation resource type name for this resource class.'''
+        return typing.cast(builtins.str, jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME"))
 
-    @builtins.property # type: ignore
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="attrArn")
     def attr_arn(self) -> builtins.str:
-        """
+        '''
         :cloudformationAttribute: Arn
-        """
-        return jsii.get(self, "attrArn")
+        '''
+        return typing.cast(builtins.str, jsii.get(self, "attrArn"))
 
-    @builtins.property # type: ignore
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="cfnProperties")
     def _cfn_properties(self) -> typing.Mapping[builtins.str, typing.Any]:
-        return jsii.get(self, "cfnProperties")
+        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.get(self, "cfnProperties"))
 
-    @builtins.property # type: ignore
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="assessmentTargetArn")
     def assessment_target_arn(self) -> builtins.str:
-        """``AWS::Inspector::AssessmentTemplate.AssessmentTargetArn``.
+        '''``AWS::Inspector::AssessmentTemplate.AssessmentTargetArn``.
 
-        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-inspector-assessmenttemplate.html#cfn-inspector-assessmenttemplate-assessmenttargetarn
-        """
-        return jsii.get(self, "assessmentTargetArn")
+        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-inspector-assessmenttemplate.html#cfn-inspector-assessmenttemplate-assessmenttargetarn
+        '''
+        return typing.cast(builtins.str, jsii.get(self, "assessmentTargetArn"))
 
-    @assessment_target_arn.setter # type: ignore
+    @assessment_target_arn.setter
     def assessment_target_arn(self, value: builtins.str) -> None:
         jsii.set(self, "assessmentTargetArn", value)
 
-    @builtins.property # type: ignore
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="durationInSeconds")
     def duration_in_seconds(self) -> jsii.Number:
-        """``AWS::Inspector::AssessmentTemplate.DurationInSeconds``.
+        '''``AWS::Inspector::AssessmentTemplate.DurationInSeconds``.
 
-        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-inspector-assessmenttemplate.html#cfn-inspector-assessmenttemplate-durationinseconds
-        """
-        return jsii.get(self, "durationInSeconds")
+        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-inspector-assessmenttemplate.html#cfn-inspector-assessmenttemplate-durationinseconds
+        '''
+        return typing.cast(jsii.Number, jsii.get(self, "durationInSeconds"))
 
-    @duration_in_seconds.setter # type: ignore
+    @duration_in_seconds.setter
     def duration_in_seconds(self, value: jsii.Number) -> None:
         jsii.set(self, "durationInSeconds", value)
 
-    @builtins.property # type: ignore
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="rulesPackageArns")
     def rules_package_arns(self) -> typing.List[builtins.str]:
-        """``AWS::Inspector::AssessmentTemplate.RulesPackageArns``.
+        '''``AWS::Inspector::AssessmentTemplate.RulesPackageArns``.
 
-        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-inspector-assessmenttemplate.html#cfn-inspector-assessmenttemplate-rulespackagearns
-        """
-        return jsii.get(self, "rulesPackageArns")
+        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-inspector-assessmenttemplate.html#cfn-inspector-assessmenttemplate-rulespackagearns
+        '''
+        return typing.cast(typing.List[builtins.str], jsii.get(self, "rulesPackageArns"))
 
-    @rules_package_arns.setter # type: ignore
+    @rules_package_arns.setter
     def rules_package_arns(self, value: typing.List[builtins.str]) -> None:
         jsii.set(self, "rulesPackageArns", value)
 
-    @builtins.property # type: ignore
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="assessmentTemplateName")
     def assessment_template_name(self) -> typing.Optional[builtins.str]:
-        """``AWS::Inspector::AssessmentTemplate.AssessmentTemplateName``.
+        '''``AWS::Inspector::AssessmentTemplate.AssessmentTemplateName``.
 
-        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-inspector-assessmenttemplate.html#cfn-inspector-assessmenttemplate-assessmenttemplatename
-        """
-        return jsii.get(self, "assessmentTemplateName")
+        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-inspector-assessmenttemplate.html#cfn-inspector-assessmenttemplate-assessmenttemplatename
+        '''
+        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "assessmentTemplateName"))
 
-    @assessment_template_name.setter # type: ignore
+    @assessment_template_name.setter
     def assessment_template_name(self, value: typing.Optional[builtins.str]) -> None:
         jsii.set(self, "assessmentTemplateName", value)
 
-    @builtins.property # type: ignore
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="userAttributesForFindings")
     def user_attributes_for_findings(
         self,
     ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union[_IResolvable_a771d0ef, _CfnTag_95fbdc29]]]]:
-        """``AWS::Inspector::AssessmentTemplate.UserAttributesForFindings``.
+        '''``AWS::Inspector::AssessmentTemplate.UserAttributesForFindings``.
 
-        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-inspector-assessmenttemplate.html#cfn-inspector-assessmenttemplate-userattributesforfindings
-        """
-        return jsii.get(self, "userAttributesForFindings")
+        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-inspector-assessmenttemplate.html#cfn-inspector-assessmenttemplate-userattributesforfindings
+        '''
+        return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union[_IResolvable_a771d0ef, _CfnTag_95fbdc29]]]], jsii.get(self, "userAttributesForFindings"))
 
-    @user_attributes_for_findings.setter # type: ignore
+    @user_attributes_for_findings.setter
     def user_attributes_for_findings(
         self,
         value: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union[_IResolvable_a771d0ef, _CfnTag_95fbdc29]]]],
@@ -348,11 +359,11 @@ class CfnAssessmentTemplateProps:
         *,
         assessment_target_arn: builtins.str,
         duration_in_seconds: jsii.Number,
-        rules_package_arns: typing.List[builtins.str],
+        rules_package_arns: typing.Sequence[builtins.str],
         assessment_template_name: typing.Optional[builtins.str] = None,
-        user_attributes_for_findings: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union[_IResolvable_a771d0ef, _CfnTag_95fbdc29]]]] = None,
+        user_attributes_for_findings: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[_IResolvable_a771d0ef, _CfnTag_95fbdc29]]]] = None,
     ) -> None:
-        """Properties for defining a ``AWS::Inspector::AssessmentTemplate``.
+        '''Properties for defining a ``AWS::Inspector::AssessmentTemplate``.
 
         :param assessment_target_arn: ``AWS::Inspector::AssessmentTemplate.AssessmentTargetArn``.
         :param duration_in_seconds: ``AWS::Inspector::AssessmentTemplate.DurationInSeconds``.
@@ -360,8 +371,8 @@ class CfnAssessmentTemplateProps:
         :param assessment_template_name: ``AWS::Inspector::AssessmentTemplate.AssessmentTemplateName``.
         :param user_attributes_for_findings: ``AWS::Inspector::AssessmentTemplate.UserAttributesForFindings``.
 
-        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-inspector-assessmenttemplate.html
-        """
+        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-inspector-assessmenttemplate.html
+        '''
         self._values: typing.Dict[str, typing.Any] = {
             "assessment_target_arn": assessment_target_arn,
             "duration_in_seconds": duration_in_seconds,
@@ -374,53 +385,53 @@ class CfnAssessmentTemplateProps:
 
     @builtins.property
     def assessment_target_arn(self) -> builtins.str:
-        """``AWS::Inspector::AssessmentTemplate.AssessmentTargetArn``.
+        '''``AWS::Inspector::AssessmentTemplate.AssessmentTargetArn``.
 
-        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-inspector-assessmenttemplate.html#cfn-inspector-assessmenttemplate-assessmenttargetarn
-        """
+        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-inspector-assessmenttemplate.html#cfn-inspector-assessmenttemplate-assessmenttargetarn
+        '''
         result = self._values.get("assessment_target_arn")
         assert result is not None, "Required property 'assessment_target_arn' is missing"
-        return result
+        return typing.cast(builtins.str, result)
 
     @builtins.property
     def duration_in_seconds(self) -> jsii.Number:
-        """``AWS::Inspector::AssessmentTemplate.DurationInSeconds``.
+        '''``AWS::Inspector::AssessmentTemplate.DurationInSeconds``.
 
-        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-inspector-assessmenttemplate.html#cfn-inspector-assessmenttemplate-durationinseconds
-        """
+        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-inspector-assessmenttemplate.html#cfn-inspector-assessmenttemplate-durationinseconds
+        '''
         result = self._values.get("duration_in_seconds")
         assert result is not None, "Required property 'duration_in_seconds' is missing"
-        return result
+        return typing.cast(jsii.Number, result)
 
     @builtins.property
     def rules_package_arns(self) -> typing.List[builtins.str]:
-        """``AWS::Inspector::AssessmentTemplate.RulesPackageArns``.
+        '''``AWS::Inspector::AssessmentTemplate.RulesPackageArns``.
 
-        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-inspector-assessmenttemplate.html#cfn-inspector-assessmenttemplate-rulespackagearns
-        """
+        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-inspector-assessmenttemplate.html#cfn-inspector-assessmenttemplate-rulespackagearns
+        '''
         result = self._values.get("rules_package_arns")
         assert result is not None, "Required property 'rules_package_arns' is missing"
-        return result
+        return typing.cast(typing.List[builtins.str], result)
 
     @builtins.property
     def assessment_template_name(self) -> typing.Optional[builtins.str]:
-        """``AWS::Inspector::AssessmentTemplate.AssessmentTemplateName``.
+        '''``AWS::Inspector::AssessmentTemplate.AssessmentTemplateName``.
 
-        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-inspector-assessmenttemplate.html#cfn-inspector-assessmenttemplate-assessmenttemplatename
-        """
+        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-inspector-assessmenttemplate.html#cfn-inspector-assessmenttemplate-assessmenttemplatename
+        '''
         result = self._values.get("assessment_template_name")
-        return result
+        return typing.cast(typing.Optional[builtins.str], result)
 
     @builtins.property
     def user_attributes_for_findings(
         self,
     ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union[_IResolvable_a771d0ef, _CfnTag_95fbdc29]]]]:
-        """``AWS::Inspector::AssessmentTemplate.UserAttributesForFindings``.
+        '''``AWS::Inspector::AssessmentTemplate.UserAttributesForFindings``.
 
-        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-inspector-assessmenttemplate.html#cfn-inspector-assessmenttemplate-userattributesforfindings
-        """
+        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-inspector-assessmenttemplate.html#cfn-inspector-assessmenttemplate-userattributesforfindings
+        '''
         result = self._values.get("user_attributes_for_findings")
-        return result
+        return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union[_IResolvable_a771d0ef, _CfnTag_95fbdc29]]]], result)
 
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -440,80 +451,78 @@ class CfnResourceGroup(
     metaclass=jsii.JSIIMeta,
     jsii_type="monocdk.aws_inspector.CfnResourceGroup",
 ):
-    """A CloudFormation ``AWS::Inspector::ResourceGroup``.
+    '''A CloudFormation ``AWS::Inspector::ResourceGroup``.
 
-    :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-inspector-resourcegroup.html
     :cloudformationResource: AWS::Inspector::ResourceGroup
-    """
+    :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-inspector-resourcegroup.html
+    '''
 
     def __init__(
         self,
         scope: _Construct_e78e779f,
         id: builtins.str,
         *,
-        resource_group_tags: typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union[_IResolvable_a771d0ef, _CfnTag_95fbdc29]]],
+        resource_group_tags: typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[_IResolvable_a771d0ef, _CfnTag_95fbdc29]]],
     ) -> None:
-        """Create a new ``AWS::Inspector::ResourceGroup``.
+        '''Create a new ``AWS::Inspector::ResourceGroup``.
 
         :param scope: - scope in which this resource is defined.
         :param id: - scoped id of the resource.
         :param resource_group_tags: ``AWS::Inspector::ResourceGroup.ResourceGroupTags``.
-        """
+        '''
         props = CfnResourceGroupProps(resource_group_tags=resource_group_tags)
 
         jsii.create(CfnResourceGroup, self, [scope, id, props])
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: _TreeInspector_1cd1894e) -> None:
-        """(experimental) Examines the CloudFormation resource and discloses attributes.
+        '''Examines the CloudFormation resource and discloses attributes.
 
         :param inspector: - tree inspector to collect and process attributes.
-
-        :stability: experimental
-        """
-        return jsii.invoke(self, "inspect", [inspector])
+        '''
+        return typing.cast(None, jsii.invoke(self, "inspect", [inspector]))
 
     @jsii.member(jsii_name="renderProperties")
     def _render_properties(
         self,
         props: typing.Mapping[builtins.str, typing.Any],
     ) -> typing.Mapping[builtins.str, typing.Any]:
-        """
+        '''
         :param props: -
-        """
-        return jsii.invoke(self, "renderProperties", [props])
+        '''
+        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "renderProperties", [props]))
 
-    @jsii.python.classproperty # type: ignore
+    @jsii.python.classproperty # type: ignore[misc]
     @jsii.member(jsii_name="CFN_RESOURCE_TYPE_NAME")
     def CFN_RESOURCE_TYPE_NAME(cls) -> builtins.str:
-        """The CloudFormation resource type name for this resource class."""
-        return jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME")
+        '''The CloudFormation resource type name for this resource class.'''
+        return typing.cast(builtins.str, jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME"))
 
-    @builtins.property # type: ignore
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="attrArn")
     def attr_arn(self) -> builtins.str:
-        """
+        '''
         :cloudformationAttribute: Arn
-        """
-        return jsii.get(self, "attrArn")
+        '''
+        return typing.cast(builtins.str, jsii.get(self, "attrArn"))
 
-    @builtins.property # type: ignore
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="cfnProperties")
     def _cfn_properties(self) -> typing.Mapping[builtins.str, typing.Any]:
-        return jsii.get(self, "cfnProperties")
+        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.get(self, "cfnProperties"))
 
-    @builtins.property # type: ignore
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="resourceGroupTags")
     def resource_group_tags(
         self,
     ) -> typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union[_IResolvable_a771d0ef, _CfnTag_95fbdc29]]]:
-        """``AWS::Inspector::ResourceGroup.ResourceGroupTags``.
+        '''``AWS::Inspector::ResourceGroup.ResourceGroupTags``.
 
-        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-inspector-resourcegroup.html#cfn-inspector-resourcegroup-resourcegrouptags
-        """
-        return jsii.get(self, "resourceGroupTags")
+        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-inspector-resourcegroup.html#cfn-inspector-resourcegroup-resourcegrouptags
+        '''
+        return typing.cast(typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union[_IResolvable_a771d0ef, _CfnTag_95fbdc29]]], jsii.get(self, "resourceGroupTags"))
 
-    @resource_group_tags.setter # type: ignore
+    @resource_group_tags.setter
     def resource_group_tags(
         self,
         value: typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union[_IResolvable_a771d0ef, _CfnTag_95fbdc29]]],
@@ -530,14 +539,14 @@ class CfnResourceGroupProps:
     def __init__(
         self,
         *,
-        resource_group_tags: typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union[_IResolvable_a771d0ef, _CfnTag_95fbdc29]]],
+        resource_group_tags: typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[_IResolvable_a771d0ef, _CfnTag_95fbdc29]]],
     ) -> None:
-        """Properties for defining a ``AWS::Inspector::ResourceGroup``.
+        '''Properties for defining a ``AWS::Inspector::ResourceGroup``.
 
         :param resource_group_tags: ``AWS::Inspector::ResourceGroup.ResourceGroupTags``.
 
-        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-inspector-resourcegroup.html
-        """
+        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-inspector-resourcegroup.html
+        '''
         self._values: typing.Dict[str, typing.Any] = {
             "resource_group_tags": resource_group_tags,
         }
@@ -546,13 +555,13 @@ class CfnResourceGroupProps:
     def resource_group_tags(
         self,
     ) -> typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union[_IResolvable_a771d0ef, _CfnTag_95fbdc29]]]:
-        """``AWS::Inspector::ResourceGroup.ResourceGroupTags``.
+        '''``AWS::Inspector::ResourceGroup.ResourceGroupTags``.
 
-        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-inspector-resourcegroup.html#cfn-inspector-resourcegroup-resourcegrouptags
-        """
+        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-inspector-resourcegroup.html#cfn-inspector-resourcegroup-resourcegrouptags
+        '''
         result = self._values.get("resource_group_tags")
         assert result is not None, "Required property 'resource_group_tags' is missing"
-        return result
+        return typing.cast(typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union[_IResolvable_a771d0ef, _CfnTag_95fbdc29]]], result)
 
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
